@@ -73,6 +73,8 @@ class StatusCode:
     FEISHU_BOUNDED = ("A0325", "飞书已绑定")
     WEIXIN_BOUNDED_OTHER = ("A0326", "微信已绑定在其他帐号了")
     FEISHU_BOUNDED_OTHER = ("A0327", "飞书已绑定在其他帐号了")
+    IS_ENTERPRISE_ACCOUNT = ("A0328", "当前帐号是企业帐号")
+    NOT_ENTERPRISE_ACCOUNT = ("A0329", "当前帐号不是企业帐号")
 
     @staticmethod
     def REQUIRED_PARAM_IS_EMPTY(message):
